<nav>
  <ul class="center">
    <li> <a href="index.html">Overview</a>
    <li> <a href="https://github.com/joaotavora/yasnippet/blob/master/README.mdown">
        Intro and Tutorial</a>
    <li class="center">Snippet
      <ul>
        <li> <a href="snippet-organization.html">Organization</a>
        <li> <a href="snippet-expansion.html">Expansion</a>
        <li> <a href="snippet-development.html">Development</a>
        <li> <a href="snippet-menu.html">Menu</a>
      </ul>
    <li> <a href="faq.html">FAQ</a>
    <li> <a href="snippet-reference.html">Reference</a>
  </ul>
</nav>
